import {Component, EventEmitter, Input, Output, ViewChild} from '@angular/core';
import {AsyncPipe} from "@angular/common";
import {DataSpinnerComponent} from "@component/data-spinner/data-spinner.component";
import {MatAccordion, MatExpansionModule, MatExpansionPanel} from "@angular/material/expansion";
import {MatChipListboxChange, MatChipsModule} from "@angular/material/chips";
import {Observable, of} from "rxjs";
import {CampusBasicInfoResponse} from "@model/campusBasicInfoResponse";
import {FormControl, ReactiveFormsModule} from "@angular/forms";
import {LectureHallResponse} from "@model/lectureHallResponse";

@Component({
  selector: 'app-schedule-tabs-lecture-hall',
  standalone: true,
  imports: [
    MatChipsModule,
    DataSpinnerComponent,
    MatExpansionModule,
    AsyncPipe,
    ReactiveFormsModule,
    MatAccordion
  ],
  templateUrl: './schedule-tabs-lecture-hall.component.html',
  styleUrl: './schedule-tabs-lecture-hall.component.css'
})
export class ScheduleTabsLectureHallComponent {
  protected campusId: number | null = null;
  protected chipLecture: FormControl = new FormControl();

  @ViewChild('lecturePanel') lecturePanel!: MatExpansionPanel;

  @Input() campuses: Observable<CampusBasicInfoResponse[]> = of([]);
  @Input() lectureHalls: Observable<LectureHallResponse[]> = of([]);

  @Output() campusSelected = new EventEmitter<number>();
  @Output() lectureHallSelected = new EventEmitter<number>();

  protected selectedCampus(event: MatChipListboxChange) {
    this.chipLecture.reset();

    if (event.value === undefined || event.value === null) {
      this.campusId = null;
      this.lectureHalls = of([]);
      return;
    }

    this.campusId = event.value;
    this.lecturePanel.open();

    this.campusSelected.emit(this.campusId!);
  }

  protected selectedLectureHall(event: MatChipListboxChange) {
    if (event.value === undefined || event.value === null)
      return;

    this.lecturePanel.close();
    this.lectureHallSelected.emit(event.value);
  }
}
